=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2010-04-19 23:33:41 +0000
+++ drizzled/cursor.cc	2010-04-21 02:28:11 +0000
@@ -1327,10 +1327,10 @@
     /*
      * This is a total hack because of the code that is
      * in write_record() in sql_insert.cc. During
-     * a REPLACE statement, a call to ha_write_row() is
-     * called.  If it fails, then a call to ha_delete_row()
+     * a REPLACE statement, a call to insertRecord() is
+     * called.  If it fails, then a call to deleteRecord()
      * is called, followed by a repeat of the original
-     * call to ha_write_row().  So, log_row_for_replication
+     * call to insertRecord().  So, log_row_for_replication
      * could be called either once or twice for a REPLACE
      * statement.  The below looks at the values of before_record
      * and after_record to determine which call to this
@@ -1468,7 +1468,7 @@
 }
 
 
-int Cursor::ha_write_row(unsigned char *buf)
+int Cursor::insertRecord(unsigned char *buf)
 {
   int error;
 
@@ -1483,7 +1483,7 @@
 
   DRIZZLE_INSERT_ROW_START(table_share->getSchemaName(), table_share->getTableName());
   setTransactionReadWrite();
-  error= write_row(buf);
+  error= doInsertRecord(buf);
   DRIZZLE_INSERT_ROW_DONE(error);
 
   if (unlikely(error))
@@ -1498,7 +1498,7 @@
 }
 
 
-int Cursor::ha_update_row(const unsigned char *old_data, unsigned char *new_data)
+int Cursor::updateRecord(const unsigned char *old_data, unsigned char *new_data)
 {
   int error;
 
@@ -1510,7 +1510,7 @@
 
   DRIZZLE_UPDATE_ROW_START(table_share->getSchemaName(), table_share->getTableName());
   setTransactionReadWrite();
-  error= update_row(old_data, new_data);
+  error= doUpdateRecord(old_data, new_data);
   DRIZZLE_UPDATE_ROW_DONE(error);
 
   if (unlikely(error))
@@ -1524,13 +1524,13 @@
   return 0;
 }
 
-int Cursor::ha_delete_row(const unsigned char *buf)
+int Cursor::deleteRecord(const unsigned char *buf)
 {
   int error;
 
   DRIZZLE_DELETE_ROW_START(table_share->getSchemaName(), table_share->getTableName());
   setTransactionReadWrite();
-  error= delete_row(buf);
+  error= doDeleteRecord(buf);
   DRIZZLE_DELETE_ROW_DONE(error);
 
   if (unlikely(error))

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2010-04-20 06:46:00 +0000
+++ drizzled/cursor.h	2010-04-21 02:28:11 +0000
@@ -47,19 +47,10 @@
 
 #define HA_MAX_ALTER_FLAGS 40
 
-
 typedef std::bitset<HA_MAX_ALTER_FLAGS> HA_ALTER_FLAGS;
 
 extern uint64_t refresh_version;  /* Increments on each reload */
 
-
-typedef bool (*qc_engine_callback)(Session *session, char *table_key,
-                                      uint32_t key_length,
-                                      uint64_t *engine_data);
-
-
-/* The Cursor for a table type.  Will be included in the Table structure */
-
 class Table;
 class TableList;
 class TableShare;
@@ -68,7 +59,6 @@
 struct order_st;
 
 class Item;
-struct st_table_log_memory_entry;
 
 class LEX;
 class Select_Lex;
@@ -159,7 +149,6 @@
   If a blob column has NULL value, then its length and blob data pointer
   must be set to 0.
 */
-
 class Cursor :public memory::SqlAlloc
 {
 protected:
@@ -254,13 +243,13 @@
   /**
     These functions represent the public interface to *users* of the
     Cursor class, hence they are *not* virtual. For the inheritance
-    interface, see the (private) functions write_row(), update_row(),
-    and delete_row() below.
+    interface, see the (private) functions doInsertRecord(), doUpdateRecord(),
+    and doDeleteRecord() below.
   */
   int ha_external_lock(Session *session, int lock_type);
-  int ha_write_row(unsigned char * buf);
-  int ha_update_row(const unsigned char * old_data, unsigned char * new_data);
-  int ha_delete_row(const unsigned char * buf);
+  int insertRecord(unsigned char * buf);
+  int updateRecord(const unsigned char * old_data, unsigned char * new_data);
+  int deleteRecord(const unsigned char * buf);
   void ha_release_auto_increment();
 
   /** to be actually called to get 'check()' functionality*/
@@ -579,17 +568,17 @@
   */
   virtual int rnd_init(bool scan)= 0;
   virtual int rnd_end() { return 0; }
-  virtual int write_row(unsigned char *)
-  {
-    return HA_ERR_WRONG_COMMAND;
-  }
-
-  virtual int update_row(const unsigned char *, unsigned char *)
-  {
-    return HA_ERR_WRONG_COMMAND;
-  }
-
-  virtual int delete_row(const unsigned char *)
+  virtual int doInsertRecord(unsigned char *)
+  {
+    return HA_ERR_WRONG_COMMAND;
+  }
+
+  virtual int doUpdateRecord(const unsigned char *, unsigned char *)
+  {
+    return HA_ERR_WRONG_COMMAND;
+  }
+
+  virtual int doDeleteRecord(const unsigned char *)
   {
     return HA_ERR_WRONG_COMMAND;
   }

=== modified file 'drizzled/item/sum.cc'
--- drizzled/item/sum.cc	2010-03-26 16:11:54 +0000
+++ drizzled/item/sum.cc	2010-04-20 18:14:52 +0000
@@ -2724,7 +2724,7 @@
     */
     return tree->unique_add(table->record[0] + table->s->null_bytes);
   }
-  if ((error= table->cursor->ha_write_row(table->record[0])) &&
+  if ((error= table->cursor->insertRecord(table->record[0])) &&
       table->cursor->is_fatal_error(error, HA_CHECK_DUP))
     return true;
   return false;

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-04-17 01:17:06 +0000
+++ drizzled/join.cc	2010-04-21 02:28:11 +0000
@@ -2357,7 +2357,7 @@
           item->save_in_result_field(1);
       }
       copy_sum_funcs(sum_funcs_end[i+1], sum_funcs_end[i]);
-      if ((write_error= table_arg->cursor->ha_write_row(table_arg->record[0])))
+      if ((write_error= table_arg->cursor->insertRecord(table_arg->record[0])))
       {
   if (create_myisam_from_heap(session, table_arg,
                                     tmp_table_param.start_recinfo,
@@ -2814,7 +2814,7 @@
     {
       int error;
       join->found_records++;
-      if ((error=table->cursor->ha_write_row(table->record[0])))
+      if ((error=table->cursor->insertRecord(table->record[0])))
       {
         if (!table->cursor->is_fatal_error(error, HA_CHECK_DUP))
           goto end;
@@ -2872,7 +2872,7 @@
   {						/* Update old record */
     table->restoreRecord();
     update_tmptable_sum_func(join->sum_funcs,table);
-    if ((error= table->cursor->ha_update_row(table->record[1],
+    if ((error= table->cursor->updateRecord(table->record[1],
                                           table->record[0])))
     {
       table->print_error(error,MYF(0));
@@ -2896,7 +2896,7 @@
   }
   init_tmptable_sum_functions(join->sum_funcs);
   copy_funcs(join->tmp_table_param.items_to_copy);
-  if ((error=table->cursor->ha_write_row(table->record[0])))
+  if ((error=table->cursor->insertRecord(table->record[0])))
   {
     if (create_myisam_from_heap(join->session, table,
                                 join->tmp_table_param.start_recinfo,
@@ -2929,7 +2929,7 @@
   copy_fields(&join->tmp_table_param);		// Groups are copied twice.
   copy_funcs(join->tmp_table_param.items_to_copy);
 
-  if (!(error= table->cursor->ha_write_row(table->record[0])))
+  if (!(error= table->cursor->insertRecord(table->record[0])))
     join->send_records++;			// New group
   else
   {
@@ -2945,7 +2945,7 @@
     }
     table->restoreRecord();
     update_tmptable_sum_func(join->sum_funcs,table);
-    if ((error= table->cursor->ha_update_row(table->record[1],
+    if ((error= table->cursor->updateRecord(table->record[1],
                                           table->record[0])))
     {
       table->print_error(error,MYF(0));

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2010-03-26 18:37:36 +0000
+++ drizzled/sql_delete.cc	2010-04-20 19:05:03 +0000
@@ -244,7 +244,7 @@
     // session->is_error() is tested to disallow delete row on error
     if (!(select && select->skip_record())&& ! session->is_error() )
     {
-      if (!(error= table->cursor->ha_delete_row(table->record[0])))
+      if (!(error= table->cursor->deleteRecord(table->record[0])))
       {
 	deleted++;
 	if (!--limit && using_limit)

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2010-04-08 16:25:53 +0000
+++ drizzled/sql_insert.cc	2010-04-20 19:05:03 +0000
@@ -721,7 +721,7 @@
 
   if (info->handle_duplicates == DUP_REPLACE || info->handle_duplicates == DUP_UPDATE)
   {
-    while ((error=table->cursor->ha_write_row(table->record[0])))
+    while ((error=table->cursor->insertRecord(table->record[0])))
     {
       uint32_t key_nr;
       /*
@@ -820,7 +820,7 @@
              !bitmap_is_subset(table->write_set, table->read_set)) ||
             table->compare_record())
         {
-          if ((error=table->cursor->ha_update_row(table->record[1],
+          if ((error=table->cursor->updateRecord(table->record[1],
                                                 table->record[0])) &&
               error != HA_ERR_RECORD_IS_THE_SAME)
           {
@@ -875,7 +875,7 @@
             (table->timestamp_field_type == TIMESTAMP_NO_AUTO_SET ||
              table->timestamp_field_type == TIMESTAMP_AUTO_SET_ON_BOTH))
         {
-          if ((error=table->cursor->ha_update_row(table->record[1],
+          if ((error=table->cursor->updateRecord(table->record[1],
 					        table->record[0])) &&
               error != HA_ERR_RECORD_IS_THE_SAME)
             goto err;
@@ -892,7 +892,7 @@
         }
         else
         {
-          if ((error=table->cursor->ha_delete_row(table->record[1])))
+          if ((error=table->cursor->deleteRecord(table->record[1])))
             goto err;
           info->deleted++;
           if (!table->cursor->has_transactions())
@@ -910,7 +910,7 @@
         table->write_set != save_write_set)
       table->column_bitmaps_set(save_read_set, save_write_set);
   }
-  else if ((error=table->cursor->ha_write_row(table->record[0])))
+  else if ((error=table->cursor->insertRecord(table->record[0])))
   {
     if (!info->ignore ||
         table->cursor->is_fatal_error(error, HA_CHECK_DUP))

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-04-20 03:20:58 +0000
+++ drizzled/sql_select.cc	2010-04-21 02:28:11 +0000
@@ -4215,7 +4215,7 @@
         copy_sum_funcs(join->sum_funcs, join->sum_funcs_end[send_group_parts]);
         if (!join->having || join->having->val_int())
         {
-          int error= table->cursor->ha_write_row(table->record[0]);
+          int error= table->cursor->insertRecord(table->record[0]);
           if (error && create_myisam_from_heap(join->session, table,
                                               join->tmp_table_param.start_recinfo,
                                                 &join->tmp_table_param.recinfo,
@@ -5344,7 +5344,7 @@
     }
     if (having && !having->val_int())
     {
-      if ((error=cursor->ha_delete_row(record)))
+      if ((error=cursor->deleteRecord(record)))
         goto err;
       error=cursor->rnd_next(record);
       continue;
@@ -5371,7 +5371,7 @@
       }
       if (table->compare_record(first_field) == 0)
       {
-        if ((error=cursor->ha_delete_row(record)))
+        if ((error=cursor->deleteRecord(record)))
           goto err;
       }
       else if (!found)
@@ -5466,7 +5466,7 @@
     }
     if (having && !having->val_int())
     {
-      if ((error=cursor->ha_delete_row(record)))
+      if ((error=cursor->deleteRecord(record)))
         goto err;
       continue;
     }
@@ -5483,7 +5483,7 @@
     if (hash_search(&hash, org_key_pos, key_length))
     {
       /* Duplicated found ; Remove the row */
-      if ((error=cursor->ha_delete_row(record)))
+      if ((error=cursor->deleteRecord(record)))
         goto err;
     }
     else

=== modified file 'drizzled/sql_union.cc'
--- drizzled/sql_union.cc	2010-02-05 04:05:31 +0000
+++ drizzled/sql_union.cc	2010-04-20 18:14:52 +0000
@@ -63,7 +63,7 @@
   if (session->is_error())
     return 1;
 
-  if ((error= table->cursor->ha_write_row(table->record[0])))
+  if ((error= table->cursor->insertRecord(table->record[0])))
   {
     /* create_myisam_from_heap will generate error if needed */
     if (table->cursor->is_fatal_error(error, HA_CHECK_DUP) &&

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2010-04-08 16:25:53 +0000
+++ drizzled/sql_update.cc	2010-04-20 18:33:21 +0000
@@ -456,7 +456,7 @@
       if (!can_compare_record || table->compare_record())
       {
         /* Non-batched update */
-        error= table->cursor->ha_update_row(table->record[1],
+        error= table->cursor->updateRecord(table->record[1],
                                             table->record[0]);
         if (!error || error == HA_ERR_RECORD_IS_THE_SAME)
 	{

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-04-18 01:42:25 +0000
+++ drizzled/statement/alter_table.cc	2010-04-20 18:14:52 +0000
@@ -1449,7 +1449,7 @@
       copy_ptr->do_copy(copy_ptr);
     }
     prev_insert_id= to->cursor->next_insert_id;
-    error= to->cursor->ha_write_row(to->record[0]);
+    error= to->cursor->insertRecord(to->record[0]);
     to->auto_increment_field_not_null= false;
     if (error)
     { 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-04-20 06:46:00 +0000
+++ drizzled/table.cc	2010-04-21 02:28:11 +0000
@@ -3343,12 +3343,12 @@
   */
   while (!table->cursor->rnd_next(new_table.record[1]))
   {
-    write_err= new_table.cursor->ha_write_row(new_table.record[1]);
+    write_err= new_table.cursor->insertRecord(new_table.record[1]);
     if (write_err)
       goto err;
   }
   /* copy row that filled HEAP table */
-  if ((write_err=new_table.cursor->ha_write_row(table->record[0])))
+  if ((write_err=new_table.cursor->insertRecord(table->record[0])))
   {
     if (new_table.cursor->is_fatal_error(write_err, HA_CHECK_DUP) ||
 	!ignore_last_dupp_key_error)

=== modified file 'plugin/archive/ha_archive.cc'
--- plugin/archive/ha_archive.cc	2010-04-18 01:56:41 +0000
+++ plugin/archive/ha_archive.cc	2010-04-20 18:14:52 +0000
@@ -692,7 +692,7 @@
   for implementing start_bulk_insert() is that we could skip
   setting dirty to true each time.
 */
-int ha_archive::write_row(unsigned char *buf)
+int ha_archive::doInsertRecord(unsigned char *buf)
 {
   int rc;
   unsigned char *read_buf= NULL;
@@ -1210,7 +1210,7 @@
 
 /*
   This method tells us that a bulk insert operation is about to occur. We set
-  a flag which will keep write_row from saying that its data is dirty. This in
+  a flag which will keep doInsertRecord from saying that its data is dirty. This in
   turn will keep selects from causing a sync to occur.
   Basically, yet another optimizations to keep compression working well.
 */

=== modified file 'plugin/archive/ha_archive.h'
--- plugin/archive/ha_archive.h	2010-04-18 01:56:41 +0000
+++ plugin/archive/ha_archive.h	2010-04-20 18:14:52 +0000
@@ -99,7 +99,7 @@
   int index_next(unsigned char * buf);
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
-  int write_row(unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
   int real_write_row(unsigned char *buf, azio_stream *writer);
   int delete_all_rows();
   int rnd_init(bool scan=1);

=== modified file 'plugin/blackhole/ha_blackhole.cc'
--- plugin/blackhole/ha_blackhole.cc	2010-04-13 07:19:47 +0000
+++ plugin/blackhole/ha_blackhole.cc	2010-04-20 18:14:52 +0000
@@ -348,7 +348,7 @@
   return("BTREE");
 }
 
-int ha_blackhole::write_row(unsigned char *)
+int ha_blackhole::doInsertRecord(unsigned char *)
 {
   return(table->next_number_field ? update_auto_increment() : 0);
 }

=== modified file 'plugin/blackhole/ha_blackhole.h'
--- plugin/blackhole/ha_blackhole.h	2010-03-30 00:17:03 +0000
+++ plugin/blackhole/ha_blackhole.h	2010-04-20 18:14:52 +0000
@@ -63,7 +63,7 @@
   uint32_t index_flags(uint32_t inx) const;
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
-  int write_row(unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
   int rnd_init(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);

=== modified file 'plugin/csv/ha_tina.cc'
--- plugin/csv/ha_tina.cc	2010-04-19 19:23:14 +0000
+++ plugin/csv/ha_tina.cc	2010-04-20 19:05:03 +0000
@@ -938,7 +938,7 @@
   of the file and appends the data. In an error case it really should
   just truncate to the original position (this is not done yet).
 */
-int ha_tina::write_row(unsigned char * buf)
+int ha_tina::doInsertRecord(unsigned char * buf)
 {
   int size;
 
@@ -998,7 +998,7 @@
   This will be called in a table scan right before the previous ::rnd_next()
   call.
 */
-int ha_tina::update_row(const unsigned char *, unsigned char * new_data)
+int ha_tina::doUpdateRecord(const unsigned char *, unsigned char * new_data)
 {
   int size;
   int rc= -1;
@@ -1043,7 +1043,7 @@
   The table will then be deleted/positioned based on the ORDER (so RANDOM,
   DESC, ASC).
 */
-int ha_tina::delete_row(const unsigned char *)
+int ha_tina::doDeleteRecord(const unsigned char *)
 {
   ha_statistic_increment(&system_status_var::ha_delete_count);
 

=== modified file 'plugin/csv/ha_tina.h'
--- plugin/csv/ha_tina.h	2010-03-30 00:17:03 +0000
+++ plugin/csv/ha_tina.h	2010-04-20 19:05:03 +0000
@@ -126,9 +126,9 @@
 
   int open(const char *name, int mode, uint32_t open_options);
   int close(void);
-  int write_row(unsigned char * buf);
-  int update_row(const unsigned char * old_data, unsigned char * new_data);
-  int delete_row(const unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
+  int doUpdateRecord(const unsigned char * old_data, unsigned char * new_data);
+  int doDeleteRecord(const unsigned char * buf);
   int rnd_init(bool scan=1);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);

=== modified file 'plugin/embedded_innodb/embedded_innodb_engine.cc'
--- plugin/embedded_innodb/embedded_innodb_engine.cc	2010-04-06 06:52:59 +0000
+++ plugin/embedded_innodb/embedded_innodb_engine.cc	2010-04-20 18:14:52 +0000
@@ -1192,7 +1192,7 @@
   return err;
 }
 
-int EmbeddedInnoDBCursor::write_row(unsigned char *)
+int EmbeddedInnoDBCursor::doInsertRecord(unsigned char *)
 {
   if (table->next_number_field)
     update_auto_increment();

=== modified file 'plugin/embedded_innodb/embedded_innodb_engine.h'
--- plugin/embedded_innodb/embedded_innodb_engine.h	2010-04-03 05:27:02 +0000
+++ plugin/embedded_innodb/embedded_innodb_engine.h	2010-04-20 18:14:52 +0000
@@ -49,7 +49,7 @@
   uint32_t index_flags(uint32_t inx) const;
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
-  int write_row(unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
   int rnd_init(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_end();

=== modified file 'plugin/heap/ha_heap.cc'
--- plugin/heap/ha_heap.cc	2010-04-01 15:54:57 +0000
+++ plugin/heap/ha_heap.cc	2010-04-20 19:05:03 +0000
@@ -323,7 +323,7 @@
 }
 
 
-int ha_heap::write_row(unsigned char * buf)
+int ha_heap::doInsertRecord(unsigned char * buf)
 {
   int res;
   ha_statistic_increment(&system_status_var::ha_write_count);
@@ -345,7 +345,7 @@
   return res;
 }
 
-int ha_heap::update_row(const unsigned char * old_data, unsigned char * new_data)
+int ha_heap::doUpdateRecord(const unsigned char * old_data, unsigned char * new_data)
 {
   int res;
   ha_statistic_increment(&system_status_var::ha_update_count);
@@ -364,7 +364,7 @@
   return res;
 }
 
-int ha_heap::delete_row(const unsigned char * buf)
+int ha_heap::doDeleteRecord(const unsigned char * buf)
 {
   int res;
   ha_statistic_increment(&system_status_var::ha_delete_count);

=== modified file 'plugin/heap/ha_heap.h'
--- plugin/heap/ha_heap.h	2010-02-04 08:14:46 +0000
+++ plugin/heap/ha_heap.h	2010-04-20 19:05:03 +0000
@@ -52,9 +52,9 @@
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
   void set_keys_for_scanning(void);
-  int write_row(unsigned char * buf);
-  int update_row(const unsigned char * old_data, unsigned char * new_data);
-  int delete_row(const unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
+  int doUpdateRecord(const unsigned char * old_data, unsigned char * new_data);
+  int doDeleteRecord(const unsigned char * buf);
   virtual void get_auto_increment(uint64_t offset, uint64_t increment,
                                   uint64_t nb_desired_values,
                                   uint64_t *first_value,

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-04-20 18:36:10 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-04-21 02:28:11 +0000
@@ -1586,7 +1586,7 @@
                      value here because it doesn't matter if we return the
                      HA_DO_INDEX_COND_PUSHDOWN bit from those "early" calls */
   start_of_scan(0),
-  num_write_row(0)
+  num_doInsertRecord(0)
 {}
 
 /*********************************************************************//**
@@ -3828,7 +3828,7 @@
 @return error code */
 UNIV_INTERN
 int
-ha_innobase::write_row(
+ha_innobase::doInsertRecord(
 /*===================*/
   unsigned char*  record) /*!< in: a row in MySQL format */
 {
@@ -3860,7 +3860,7 @@
   if ((sql_command == SQLCOM_ALTER_TABLE
        || sql_command == SQLCOM_CREATE_INDEX
        || sql_command == SQLCOM_DROP_INDEX)
-      && num_write_row >= 10000) {
+      && num_doInsertRecord >= 10000) {
     /* ALTER TABLE is COMMITted at every 10000 copied rows.
     The IX table lock for the original table has to be re-issued.
     As this method will be called on a temporary table where the
@@ -3873,7 +3873,7 @@
     dict_table_t* src_table;
     enum lock_mode  mode;
 
-    num_write_row = 0;
+    num_doInsertRecord = 0;
 
     /* Commit the transaction.  This will release the table
     locks, so they have to be acquired again. */
@@ -3920,7 +3920,7 @@
     }
   }
 
-  num_write_row++;
+  num_doInsertRecord++;
 
   /* This is the case where the table has an auto-increment column */
   if (table->next_number_field && record == table->record[0]) {
@@ -4211,7 +4211,7 @@
 @return error number or 0 */
 UNIV_INTERN
 int
-ha_innobase::update_row(
+ha_innobase::doUpdateRecord(
 /*====================*/
   const unsigned char*  old_row,/*!< in: old row in MySQL format */
   unsigned char*    new_row)/*!< in: new row in MySQL format */
@@ -4318,7 +4318,7 @@
 @return error number or 0 */
 UNIV_INTERN
 int
-ha_innobase::delete_row(
+ha_innobase::doDeleteRecord(
 /*====================*/
   const unsigned char*  record) /*!< in: a row in MySQL format */
 {
@@ -5955,7 +5955,7 @@
   if (session_sql_command(user_session) != SQLCOM_TRUNCATE) {
   fallback:
     /* We only handle TRUNCATE TABLE t as a special case.
-    DELETE FROM t will have to use ha_innobase::delete_row(),
+    DELETE FROM t will have to use ha_innobase::doDeleteRecord(),
     because DELETE is transactional while TRUNCATE is not. */
     return(errno=HA_ERR_WRONG_COMMAND);
   }
@@ -5964,7 +5964,7 @@
 
   error = row_truncate_table_for_mysql(prebuilt->table, prebuilt->trx);
   if (error == DB_ERROR) {
-    /* Cannot truncate; resort to ha_innobase::delete_row() */
+    /* Cannot truncate; resort to ha_innobase::doDeleteRecord() */
     goto fallback;
   }
 
@@ -6527,7 +6527,7 @@
       /* We need to reset the prebuilt value too, otherwise
       checks for values greater than the last value written
       to the table will fail and the autoinc counter will
-      not be updated. This will force write_row() into
+      not be updated. This will force doInsertRecord() into
       attempting an update of the table's AUTOINC counter. */
 
       prebuilt->autoinc_last_value = 0;
@@ -7775,7 +7775,7 @@
   meaningless for other statements e.g, LOAD etc. Subsequent calls to
   this method for the same statement results in different values which
   don't make sense. Therefore we store the value the first time we are
-  called and count down from that as rows are written (see write_row()).
+  called and count down from that as rows are written (see doInsertRecord()).
   */
 
   trx = prebuilt->trx;
@@ -7833,13 +7833,13 @@
         prebuilt->table, prebuilt->autoinc_last_value);
     }
   } else {
-    /* This will force write_row() into attempting an update
+    /* This will force doInsertRecord() into attempting an update
     of the table's AUTOINC counter. */
     prebuilt->autoinc_last_value = 0;
   }
 
   /* The increment to be used to increase the AUTOINC value, we use
-  this in write_row() and update_row() to increase the autoinc counter
+  this in doInsertRecord() and doUpdateRecord() to increase the autoinc counter
   for columns that are filled by the user. We need the offset and
   the increment. */
   prebuilt->autoinc_offset = offset;

=== modified file 'plugin/innobase/handler/ha_innodb.h'
--- plugin/innobase/handler/ha_innodb.h	2010-04-19 20:57:43 +0000
+++ plugin/innobase/handler/ha_innodb.h	2010-04-21 02:28:11 +0000
@@ -80,7 +80,7 @@
 	uint		last_match_mode;/* match mode of the latest search:
 					ROW_SEL_EXACT, ROW_SEL_EXACT_PREFIX,
 					or undefined */
-	uint		num_write_row;	/*!< number of write_row() calls */
+	uint		num_doInsertRecord;	/*!< number of doInsertRecord() calls */
 
 	UNIV_INTERN uint store_key_val_for_row(uint keynr, char* buff, 
                                    uint buff_len, const unsigned char* record);
@@ -130,9 +130,9 @@
 	UNIV_INTERN double scan_time();
 	UNIV_INTERN double read_time(uint index, uint ranges, ha_rows rows);
 
-	UNIV_INTERN int write_row(unsigned char * buf);
-	UNIV_INTERN int update_row(const unsigned char * old_data, unsigned char * new_data);
-	UNIV_INTERN int delete_row(const unsigned char * buf);
+	UNIV_INTERN int doInsertRecord(unsigned char * buf);
+	UNIV_INTERN int doUpdateRecord(const unsigned char * old_data, unsigned char * new_data);
+	UNIV_INTERN int doDeleteRecord(const unsigned char * buf);
 	UNIV_INTERN bool was_semi_consistent_read();
 	UNIV_INTERN void try_semi_consistent_read(bool yes);
 	UNIV_INTERN void unlock_row();

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2010-04-13 07:19:47 +0000
+++ plugin/myisam/ha_myisam.cc	2010-04-20 19:05:03 +0000
@@ -640,7 +640,7 @@
   return mi_close(tmp);
 }
 
-int ha_myisam::write_row(unsigned char *buf)
+int ha_myisam::doInsertRecord(unsigned char *buf)
 {
   ha_statistic_increment(&system_status_var::ha_write_count);
 
@@ -1031,7 +1031,7 @@
 
 
 
-int ha_myisam::update_row(const unsigned char *old_data, unsigned char *new_data)
+int ha_myisam::doUpdateRecord(const unsigned char *old_data, unsigned char *new_data)
 {
   ha_statistic_increment(&system_status_var::ha_update_count);
   if (table->timestamp_field_type & TIMESTAMP_AUTO_SET_ON_UPDATE)
@@ -1039,7 +1039,7 @@
   return mi_update(file,old_data,new_data);
 }
 
-int ha_myisam::delete_row(const unsigned char *buf)
+int ha_myisam::doDeleteRecord(const unsigned char *buf)
 {
   ha_statistic_increment(&system_status_var::ha_delete_count);
   return mi_delete(file,buf);

=== modified file 'plugin/myisam/ha_myisam.h'
--- plugin/myisam/ha_myisam.h	2010-02-04 08:14:46 +0000
+++ plugin/myisam/ha_myisam.h	2010-04-20 19:05:03 +0000
@@ -44,9 +44,9 @@
 
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
-  int write_row(unsigned char * buf);
-  int update_row(const unsigned char * old_data, unsigned char * new_data);
-  int delete_row(const unsigned char * buf);
+  int doInsertRecord(unsigned char * buf);
+  int doUpdateRecord(const unsigned char * old_data, unsigned char * new_data);
+  int doDeleteRecord(const unsigned char * buf);
   int index_read_map(unsigned char *buf, const unsigned char *key, drizzled::key_part_map keypart_map,
                      enum drizzled::ha_rkey_function find_flag);
   int index_read_idx_map(unsigned char *buf, uint32_t index, const unsigned char *key,

=== modified file 'plugin/pbxt/src/ha_pbxt.cc'
--- plugin/pbxt/src/ha_pbxt.cc	2010-04-14 16:29:40 +0000
+++ plugin/pbxt/src/ha_pbxt.cc	2010-04-20 19:05:03 +0000
@@ -2628,7 +2628,7 @@
 */
 
 /*
- * write_row() inserts a row. No extra() hint is given currently if a bulk load
+ * doInsertRecord() inserts a row. No extra() hint is given currently if a bulk load
  * is happeneding. buf() is a byte array of data. You can use the field
  * information to extract the data from the native byte array type.
  * Example of this would be:
@@ -2641,26 +2641,26 @@
  * ha_berekly.cc has an example of how to store it intact by "packing" it
  * for ha_berkeley's own native storage type.
 
- * See the note for update_row() on auto_increments and timestamps. This
- * case also applied to write_row().
+ * See the note for doUpdateRecord() on auto_increments and timestamps. This
+ * case also applied to doInsertRecord().
 
  * Called from item_sum.cc, item_sum.cc, sql_acl.cc, sql_insert.cc,
  * sql_insert.cc, sql_select.cc, sql_table.cc, sql_udf.cc, and sql_update.cc.
  */
-int ha_pbxt::write_row(byte *buf)
+int ha_pbxt::doInsertRecord(byte *buf)
 {
 	int err = 0;
 
 	ASSERT_NS(pb_ex_in_use);
 
-	XT_PRINT1(pb_open_tab->ot_thread, "write_row (%s)\n", pb_share->sh_table_path->ps_path);
+	XT_PRINT1(pb_open_tab->ot_thread, "doInsertRecord (%s)\n", pb_share->sh_table_path->ps_path);
 	XT_DISABLED_TRACE(("INSERT tx=%d val=%d\n", (int) pb_open_tab->ot_thread->st_xact_data->xd_start_xn_id, (int) XT_GET_DISK_4(&buf[1])));
 	//statistic_increment(ha_write_count,&LOCK_status);
 #ifdef PBMS_ENABLED
 	PBMSResultRec result;
-	err = pbms_write_row_blobs(table, buf, &result);
+	err = pbms_doInsertRecord_blobs(table, buf, &result);
 	if (err) {
-		xt_logf(XT_NT_ERROR, "pbms_write_row_blobs() Error: %s", result.mr_message);
+		xt_logf(XT_NT_ERROR, "pbms_doInsertRecord_blobs() Error: %s", result.mr_message);
 		return err;
 	}
 #endif
@@ -2673,12 +2673,12 @@
 			/* Commit and restart the transaction. */
 			XTThreadPtr thread = pb_open_tab->ot_thread;
 
-			XT_PRINT0(thread, "xt_xn_commit in write_row\n");
+			XT_PRINT0(thread, "xt_xn_commit in doInsertRecord\n");
 			if (!xt_xn_commit(thread)) {
 				err = xt_ha_pbxt_thread_error_for_mysql(pb_mysql_thd, thread, pb_ignore_dup_key);
 				return err;
 			}
-			XT_PRINT0(thread, "xt_xn_begin in write_row\n");
+			XT_PRINT0(thread, "xt_xn_begin in doInsertRecord\n");
 			if (!xt_xn_begin(thread)) {
 				err = xt_ha_pbxt_thread_error_for_mysql(pb_mysql_thd, thread, pb_ignore_dup_key);
 				return err;
@@ -2764,14 +2764,14 @@
 #endif
 
 /*
- * Yes, update_row() does what you expect, it updates a row. old_data will have
+ * Yes, doUpdateRecord() does what you expect, it updates a row. old_data will have
  * the previous row record in it, while new_data will have the newest data in
  * it. Keep in mind that the server can do updates based on ordering if an ORDER BY
  * clause was used. Consecutive ordering is not guarenteed.
  *
  * Called from sql_select.cc, sql_acl.cc, sql_update.cc, and sql_insert.cc.
  */
-int ha_pbxt::update_row(const byte * old_data, byte * new_data)
+int ha_pbxt::doUpdateRecord(const byte * old_data, byte * new_data)
 {
 	int						err = 0;
 	register XTThreadPtr	self = pb_open_tab->ot_thread;
@@ -2803,9 +2803,9 @@
 		xt_logf(XT_NT_ERROR, "update_row:pbms_delete_row_blobs() Error: %s", result.mr_message);
 		return err;
 	}
-	err = pbms_write_row_blobs(table, new_data, &result);
+	err = pbms_doInsertRecord_blobs(table, new_data, &result);
 	if (err) { 
-		xt_logf(XT_NT_ERROR, "update_row:pbms_write_row_blobs() Error: %s", result.mr_message);
+		xt_logf(XT_NT_ERROR, "update_row:pbms_doInsertRecord_blobs() Error: %s", result.mr_message);
 		goto pbms_done;
 	}
 #endif
@@ -2850,7 +2850,7 @@
  * Called in sql_delete.cc, sql_insert.cc, and sql_select.cc. In sql_select it is
  * used for removing duplicates while in insert it is used for REPLACE calls.
 */
-int ha_pbxt::delete_row(const byte * buf)
+int ha_pbxt::doDeleteRecord(const byte * buf)
 {
 	int err = 0;
 
@@ -4735,7 +4735,7 @@
 						 * this avoids taking locks on the rows that are read
 						 * Which leads to the assertion failure:
 						 * int XTRowLocks::xt_make_lock_permanent(XTOpenTable*, XTRowLockList*)(lock_xt.cc:646) item
-						 * after the transaction is committed in write_row.
+						 * after the transaction is committed in doInsertRecord.
 						 */
 						pb_open_tab->ot_for_update = FALSE;
 						break;
@@ -4874,9 +4874,9 @@
 		 *
 		 * So, this is the correct place to start a statement transaction.
 		 *
-		 * Note: if trans_register_ha() is not called before ha_write_row(), then 
+		 * Note: if trans_register_ha() is not called before insertRecord(), then 
 		 * PBXT is not registered correctly as a modification transaction.
-		 * (mark_trx_read_write call in ha_write_row).
+		 * (mark_trx_read_write call in insertRecord).
 		 * This leads to 2-phase commit not being called as it should when
 		 * binary logging is enabled.
 		 */

=== modified file 'plugin/pbxt/src/ha_pbxt.h'
--- plugin/pbxt/src/ha_pbxt.h	2010-04-20 00:04:22 +0000
+++ plugin/pbxt/src/ha_pbxt.h	2010-04-21 02:28:11 +0000
@@ -244,9 +244,9 @@
                                  MX_ULONGLONG_T *nb_reserved_values);
 	void	set_auto_increment(Field *nr);
 
-	int		write_row(byte * buf);
-	int		update_row(const byte * old_data, byte * new_data);
-	int		delete_row(const byte * buf);
+	int		doInsertRecord(byte * buf);
+	int		doUpdateRecord(const byte * old_data, byte * new_data);
+	int		doDeleteRecord(const byte * buf);
 
 	/* Index access functions: */
 	int		xt_index_in_range(register XTOpenTablePtr ot, register XTIndexPtr ind, register XTIdxSearchKeyPtr search_key, byte *buf);

